@@ -27,6 +27,8 @@ from contextlib import contextmanager
 Private class that makes all the action
 """
 
+TIMEOUT = 5
+
 
 class SatFelDownloader:
     def __init__(self, credentials, url_get_fel, request_session=requests.Session()):
@@ -41,7 +43,9 @@ class SatFelDownloader:
             "password": self._credentials.password,
             "operacion": "ACEPTAR",
         }
-        r = self._session.post("https://farm3.sat.gob.gt/menu/init.do", data=login_dict)
+        r = self._session.post(
+            "https://farm3.sat.gob.gt/menu/init.do", data=login_dict, timeout=TIMEOUT
+        )
         r.raise_for_status()
         bs = BeautifulSoup(r.text, features="html.parser")
         logging.info("Did login")
@@ -54,7 +58,7 @@ class SatFelDownloader:
 
     def _get_invoices_headers(self, filter: SATFELFilters):
         logging.info("CALL URL GET FEL")
-        self._session.get(self._url_get_fel)
+        self._session.get(self._url_get_fel, timeout=TIMEOUT)
         operation_param = filter.tipo
         cookie = self._session.cookies.get("ACCESS_TOKEN")
         dict_query = {
@@ -72,7 +76,8 @@ class SatFelDownloader:
             + urlencode(dict_query)
         )
         header = {"authtoken": "token " + cookie}
-        r = self._session.get(url, headers=header)
+        r = self._session.get(url, headers=header, timeout=TIMEOUT)
+        r.raise_for_status()
         json_response = r.json()["detalle"]["data"]
         return json_response
 
@@ -86,7 +91,7 @@ class SatFelDownloader:
             "receptor": invoice["nitReceptor"],
         }
 
-        r = self._session.post(url, json=invoice)
+        r = self._session.post(url, json=invoice, timeout=TIMEOUT)
         if r.status_code == 200:
             base64encoded = r.json()[0]
             bytes = base64.b64decode(base64encoded)
@@ -121,7 +126,7 @@ class SatFelDownloader:
         url += urlencode(dict_query)
         cookie = self._session.cookies.get("ACCESS_TOKEN")
         header = {"authtoken": "token " + cookie}
-        r = self._session.post(url, headers=header, json=[invoice])
+        r = self._session.post(url, headers=header, json=[invoice], timeout=TIMEOUT)
         if r.status_code == 500:
             logging.warn("Did get 500 error trying pdf contingency")
             return self._process_contingency_pdf(invoice, "pdf-contingency", received)
@@ -183,18 +188,32 @@ class SatFelDownloader:
         receptor = emission_data.select("Receptor")[0]
         lines = emission_data.select("Item")
         currency = general_data["CodigoMoneda"]
+        
         try:
+             
             issue_date = datetime.strptime(
                 general_data["FechaHoraEmision"], "%Y-%m-%dT%H:%M:%S%z"
             )
         except ValueError:
-            issue_date = datetime.strptime(
+            try:
+                issue_date = datetime.strptime(
                 general_data["FechaHoraEmision"], "%Y-%m-%dT%H:%M:%S.%f%z"
-            )
+                )
+            except:
+                try:
+                    issue_date = datetime.strptime(
+                    general_data["FechaHoraEmision"], "%Y-%m-%dT%H:%M:%S.%f"
+                    )
+                except:
+                    issue_date = datetime.strptime(
+                    general_data["FechaHoraEmision"], "%Y-%m-%dT%H:%M:%S"
+                    )
+            
         invoice_type = general_data["Tipo"]
         vat_affiliation = issuer["AfiliacionIVA"]
         stablisment_number = issuer["CodigoEstablecimiento"]
-        issuer_email = issuer["CorreoEmisor"]
+        
+        issuer_email = issuer["CorreoEmisor"] if "CorreoEmisor" in issuer else None
         issuernit = issuer["NITEmisor"]
         commercial_name = issuer["NombreComercial"]
         issuer_name = issuer["NombreEmisor"]
@@ -277,7 +296,7 @@ class SatFelDownloader:
     def get_xml_content(self, invoice, received=True):
         return self._get_response(
             invoice=invoice, filetype="xml", received=received
-        ).content
+        )[0].content
 
     def get_xml(self, invoice, save_in_dir=None, received=True):
         r, _ = self._get_response(invoice=invoice, filetype="xml", received=received)
